==> ratis-thirdparty-1.0.3-src.tar.gz: ratis-thirdparty-1.0.3/test/src/main/java/org/apache/ratis/thirdparty/demo/common/SslConfig.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ratis.thirdparty.demo.common;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

public class SslConfig {
  // TODO: allow configure cipher suites
  private final List<String> tlsCipherSuitesWithEncryption = Collections.unmodifiableList(Arrays.asList(
      "TLS_RSA_WITH_AES_128_GCM_SHA256",
      "TLS_RSA_WITH_AES_128_CBC_SHA",
      "SSL_RSA_WITH_3DES_EDE_CBC_SHA"));

  // "RSA" in this case refers to the key exchange algorithm,
  // "SHA" refers to the message digest algorithm to provide integrity
  // "NULL" is the encryption algorithm, to disable encryption.
  // TODO: support NULL cipher from tcnative
  private final List<String> tlsCipherSuitesNoEncryption = Collections.singletonList("TLS_RSA_WITH_AES_128_GCM_SHA256");

  private final boolean encryption;

  protected SslConfig(boolean encryption) {
    this.encryption = encryption;
  }

  public boolean encryptionEnabled() {
    return encryption;
  }

  public List<String> getTlsCipherSuitesWithEncryption() {
    return tlsCipherSuitesWithEncryption;
  }

  public List<String> getTlsCipherSuitesNoEncryption() {
    return tlsCipherSuitesNoEncryption;
  }

}

==> ratis-thirdparty-1.0.6-src.tar.gz: ratis-thirdparty-1.0.6/test/src/main/java/org/apache/ratis/thirdparty/demo/common/SslConfig.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ratis.thirdparty.demo.common;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

public class SslConfig {
  // TODO: allow configure cipher suites
  private final List<String> tlsCipherSuitesWithEncryption = Collections.unmodifiableList(Arrays.asList(
      "TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384",
      "TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256",
      "TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256",
      "TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384",
      "TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA",
      "TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA",
      "TLS_RSA_WITH_AES_128_GCM_SHA256",
      "TLS_RSA_WITH_AES_128_CBC_SHA",
      "TLS_RSA_WITH_AES_256_CBC_SHA",
      "TLS_AES_128_GCM_SHA256",
      "TLS_AES_256_GCM_SHA384",
      "TLS_AES_128_GCM_SHA256",
      "TLS_AES_256_GCM_SHA384",
      "TLS_AES_128_GCM_SHA256",
      "TLS_AES_256_GCM_SHA384",
      "TLS_CHACHA20_POLY1305_SHA256"
  ));

  private final boolean encryption;

  protected SslConfig(boolean encryption) {
    this.encryption = encryption;
  }

  public boolean encryptionEnabled() {
    return encryption;
  }

  public List<String> getTlsCipherSuitesWithEncryption() {
    return tlsCipherSuitesWithEncryption;
  }

  public List<String> getTlsCipherSuitesNoEncryption() {
    // TODO define list without encrpytion
    return tlsCipherSuitesWithEncryption;
  }

}
